summaryrefslogtreecommitdiffstats
path: root/Source/cmCableDefineSetCommand.cxx
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
committerBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
commitd0a8794746f6de026f1c69652cd09caf8be9cfab (patch)
tree2143ad59bf1fef6f340dd7fb199f556eadff0ef4 /Source/cmCableDefineSetCommand.cxx
parente5e2a57bfbf1aac2c265e894db82d2b2d5673084 (diff)
downloadCMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.zip
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.gz
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.bz2
ENH: CABIL -> CABLE rename.
Diffstat (limited to 'Source/cmCableDefineSetCommand.cxx')
-rw-r--r--Source/cmCableDefineSetCommand.cxx16
1 files changed, 8 insertions, 8 deletions
diff --git a/Source/cmCableDefineSetCommand.cxx b/Source/cmCableDefineSetCommand.cxx
index 725ea0e..95f0218 100644
--- a/Source/cmCableDefineSetCommand.cxx
+++ b/Source/cmCableDefineSetCommand.cxx
@@ -13,14 +13,14 @@
See COPYRIGHT.txt for copyright details.
=========================================================================*/
-#include "cmCabilDefineSetCommand.h"
+#include "cmCableDefineSetCommand.h"
#include "cmCacheManager.h"
#include "cmRegularExpression.h"
-// cmCabilDefineSetCommand
-bool cmCabilDefineSetCommand::Invoke(std::vector<std::string>& args)
+// cmCableDefineSetCommand
+bool cmCableDefineSetCommand::Invoke(std::vector<std::string>& args)
{
if(args.size() < 2)
{
@@ -44,9 +44,9 @@ bool cmCabilDefineSetCommand::Invoke(std::vector<std::string>& args)
/**
* Write the CABIL configuration code to define this Set.
*/
-void cmCabilDefineSetCommand::WriteConfiguration(std::ostream& os) const
+void cmCableDefineSetCommand::WriteConfiguration(std::ostream& os) const
{
cmRegularExpression needCdataBlock("[&<>]");
@@ -77,13 +77,13 @@ void cmCabilDefineSetCommand::WriteConfiguration(std::ostream& os) const
/**
* Given the string representing a set element, automatically generate
* the CABIL element tag for it.
*
* **This function determines how the output language of all
- * CABIL-generated wrappers will look!**
+ * CABLE-generated wrappers will look!**
*/
std::string
-cmCabilDefineSetCommand::GenerateTag(const std::string& element) const
+cmCableDefineSetCommand::GenerateTag(const std::string& element) const
{
// Hold the regular expressions for matching against the element.
cmRegularExpression regex;
@@ -44,9 +44,9 @@ bool cmCabilDefineSetCommand::Invoke(std::vector<std::string>& args)
/**
- * Write the CABIL configuration code to define this Set.
+ * Write the CABLE configuration code to define this Set.
*/
@@ -77,13 +77,13 @@ void cmCabilDefineSetCommand::WriteConfiguration(std::ostream& os) const
/**
* Given the string representing a set element, automatically generate
- * the CABIL element tag for it.
+ * the CABLE element tag for it.
*
* **This function determines how the output language of all